aboutsummaryrefslogtreecommitdiff
path: root/bpkg/rep-fetch.hxx
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2022-01-31 12:24:28 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2022-02-03 16:15:30 +0300
commitfafc5727732c7df2c98b123292f483411e0050e3 (patch)
tree2d67d33a557e82a694ba9d48a90cad99fd33e49f /bpkg/rep-fetch.hxx
parent85b7dc75597386777ebe1f7158e798eff968a4bf (diff)
Add support for bootstrap-build and root-build values in package manifest
Diffstat (limited to 'bpkg/rep-fetch.hxx')
-rw-r--r--bpkg/rep-fetch.hxx9
1 files changed, 6 insertions, 3 deletions
diff --git a/bpkg/rep-fetch.hxx b/bpkg/rep-fetch.hxx
index 9a9a18e..b9d458f 100644
--- a/bpkg/rep-fetch.hxx
+++ b/bpkg/rep-fetch.hxx
@@ -53,15 +53,18 @@ namespace bpkg
// If requested, expand the file-referencing package manifest values
// (description, changes, etc), setting them to the contents of files they
// refer to and set the potentially absent description-type value to the
// effective description type (see libbpkg/manifest.hxx). Note that for pkg
// repositories such values are expanded at the repository creation time.
//
rep_fetch_data
rep_fetch (const common_options&,
const dir_path* configuration,
const repository_location&,
bool ignore_unknown,
- bool expand_values);
+ bool expand_values,
+ bool load_buildfiles);
// Add (or update) repository locations to the configuration and fetch
// them. If shallow is true, then don't fetch their prerequisite and/or
@@ -53,15 +53,18 @@ namespace bpkg
// (description, changes, etc), setting them to the contents of files they
// refer to and set the potentially absent description-type value to the
- // effective description type (see libbpkg/manifest.hxx). Note that for pkg
- // repositories such values are expanded at the repository creation time.
+ // effective description type (see libbpkg/manifest.hxx) and load the
+ // bootstrap and root buildfiles into the respective *-build values. Note
+ // that for pkg repositories such values are expanded/loaded at the
+ // repository creation time.
//
rep_fetch_data